==> scandeval-16.1.0.tar.gz: scandeval-16.1.0/docs/leaderboards/Monolingual/french.md <==
---
hide:
    - toc
---
# 🇫🇷 French

See the [leaderboard page](/leaderboards) for more information about all the columns.

/// tab | Generative Leaderboard
<iframe title="" aria-label="Table" id="datawrapper-chart-JLrdH" src="https://datawrapper.dwcdn.net/JLrdH" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="799" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | NLU Leaderboard
<iframe title="" aria-label="Table" id="datawrapper-chart-4YpPx" src="https://datawrapper.dwcdn.net/4YpPx" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="775" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | Generative Scatter Plot
<iframe title="Performance of Generative Language Models on French Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-Xuian" src="https://datawrapper.dwcdn.net/Xuian/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | NLU Scatter Plot
<iframe title="Performance of Language Models on French NLU Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-8sGjT" src="https://datawrapper.dwcdn.net/8sGjT/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

==> scandeval-16.5.0.tar.gz: scandeval-16.5.0/docs/leaderboards/Monolingual/french.md <==
---
hide:
    - toc
---
# 🇫🇷 French

See the [leaderboard page](/leaderboards) for more information about all the columns.

/// tab | Generative Leaderboard
<iframe title="" aria-label="Table" id="datawrapper-chart-JLrdH" src="https://datawrapper.dwcdn.net/JLrdH" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="799" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | NLU Leaderboard
<iframe title="" aria-label="Table" id="datawrapper-chart-4YpPx" src="https://datawrapper.dwcdn.net/4YpPx" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="775" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | Generative Scatter Plot
<iframe title="Performance of Generative Language Models on French Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-Xuian" src="https://datawrapper.dwcdn.net/Xuian/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | NLU Scatter Plot
<iframe title="Performance of Language Models on French NLU Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-8sGjT" src="https://datawrapper.dwcdn.net/8sGjT/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

<!-- This disables the requirement that all lines must be shorter than 88 characters -->
<!-- markdownlint-configure-file { "MD013": false } -->
